#[non_exhaustive]pub struct ListQueryExecutionsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
max_results: Option<i32>The maximum number of query executions to return in this request.
work_group: Option<String>The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.
Implementations
Sourceimpl ListQueryExecutionsInput
impl ListQueryExecutionsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of query executions to return in this request.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.
Sourceimpl ListQueryExecutionsInput
impl ListQueryExecutionsInput
Sourcepub fn builder() -> ListQueryExecutionsInputBuilder
pub fn builder() -> ListQueryExecutionsInputBuilder
Creates a new builder-style object to manufacture ListQueryExecutionsInput.